@@ -2,30 +2,8 @@
 set -eu -o pipefail
 
 scriptdir="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
-
-cleanup_cmd=""
-trap 'eval ${cleanup_cmd}' EXIT
-function defer {
-	[ -n "${cleanup_cmd}" ] && cleanup_cmd="${cleanup_cmd}; "
-	cleanup_cmd="${cleanup_cmd}$1"
-}
-
-function INFO() {
-	echo "TEST| [INFO] $*"
-}
-
-function WARNING() {
-	echo >&2 "TEST| [WARNING] $*"
-}
-
-function ERROR() {
-	echo >&2 "TEST| [ERROR] $*"
-}
-
-if [[ ${BASH_VERSINFO:-0} -lt 4 ]]; then
-	ERROR "Bash version is too old: ${BASH_VERSION}"
-	exit 1
-fi
+# shellcheck source=common.inc.sh
+source "${scriptdir}/common.inc.sh"
 
 if [ "$#" -ne 1 ]; then
 	ERROR "Usage: $0 FILE.yaml"
@@ -132,6 +110,12 @@ if [ "$got" != "$expected" ]; then
 	exit 1
 fi
 
+INFO "Testing limactl command with escaped characters"
+limactl shell "$NAME" bash -c "$(echo -e '\n\techo foo\n\techo bar')"
+
+INFO "Testing limactl command with quotes"
+limactl shell "$NAME" bash -c "echo 'foo \"bar\"'"
+
 if [[ -n ${CHECKS["systemd"]} ]]; then
 	set -x
 	if ! limactl shell "$NAME" systemctl is-system-running --wait; then
@@ -147,27 +131,17 @@ if [[ -n ${CHECKS["systemd"]} ]]; then
 fi
 
 if [[ -n ${CHECKS["mount-home"]} ]]; then
-	hometmp="$HOME/lima-test-tmp"
-	INFO "Testing home access (\"$hometmp\")"
-	rm -rf "$hometmp"
-	mkdir -p "$hometmp"
-	defer "rm -rf \"$hometmp\""
-	echo "random-content-${RANDOM}" >"$hometmp/random"
-	expected="$(cat "$hometmp/random")"
-	got="$(limactl shell "$NAME" cat "$hometmp/random")"
-	INFO "$hometmp/random: expected=${expected}, got=${got}"
-	if [ "$got" != "$expected" ]; then
-		ERROR "Home directory is not shared?"
-		exit 1
-	fi
+	"${scriptdir}"/test-mount-home.sh "$NAME"
 fi
 
+# Use GHCR to avoid hitting Docker Hub rate limit
+nginx_image="ghcr.io/stargz-containers/nginx:1.19-alpine-org"
+alpine_image="ghcr.io/containerd/alpine:3.14.0"
+
 if [[ -n ${CHECKS["containerd-user"]} ]]; then
 	INFO "Run a nginx container with port forwarding 127.0.0.1:8080"
 	set -x
 	limactl shell "$NAME" nerdctl info
-	# Use GHCR to avoid hitting Docker Hub rate limit
-	nginx_image="ghcr.io/stargz-containers/nginx:1.19-alpine-org"
 	limactl shell "$NAME" nerdctl pull --quiet ${nginx_image}
 	limactl shell "$NAME" nerdctl run -d --name nginx -p 127.0.0.1:8080:80 ${nginx_image}
 
@@ -183,7 +157,6 @@ if [[ -n ${CHECKS["containerd-user"]} ]]; then
 		mkdir -p "$hometmp"
 		defer "rm -rf \"$hometmp\""
 		set -x
-		alpine_image="ghcr.io/containerd/alpine:3.14.0"
 		limactl shell "$NAME" nerdctl pull --quiet ${alpine_image}
 		echo "random-content-${RANDOM}" >"$hometmp/random"
 		expected="$(cat "$hometmp/random")"
@@ -213,6 +186,34 @@ if [[ -n ${CHECKS["port-forwards"]} ]]; then
 		limactl shell "$NAME" sudo zypper in -y netcat-openbsd
 	fi
 	"${scriptdir}/test-port-forwarding.pl" "${NAME}"
+
+	if [[ -n ${CHECKS["containerd-user"]} || ${NAME} == "alpine" ]]; then
+		INFO "Testing that 'nerdctl run' binds to 0.0.0.0 by default and is forwarded to the host"
+		if [ "$(uname)" = "Darwin" ]; then
+			# macOS runners seem to use `localhost` as the hostname, so the perl lookup just returns `127.0.0.1`
+			hostip=$(system_profiler SPNetworkDataType -json | jq -r 'first(.SPNetworkDataType[] | select(.ip_address) | .ip_address) | first')
+		else
+			hostip=$(perl -MSocket -MSys::Hostname -E 'say inet_ntoa(scalar gethostbyname(hostname()))')
+		fi
+		if [ -n "${hostip}" ]; then
+			sudo=""
+			if [ "${NAME}" = "alpine" ]; then
+				arch=$(limactl info | jq -r .defaultTemplate.arch)
+				nerdctl=$(limactl info | jq -r ".defaultTemplate.containerd.archives[] | select(.arch==\"$arch\").location")
+				curl -Lso nerdctl-full.tgz "${nerdctl}"
+				limactl shell "$NAME" sudo apk add containerd
+				limactl shell "$NAME" sudo rc-service containerd start
+				limactl shell "$NAME" sudo tar xzf "${PWD}/nerdctl-full.tgz" -C /usr/local
+				rm nerdctl-full.tgz
+				sudo="sudo"
+			fi
+			limactl shell "$NAME" $sudo nerdctl info
+			limactl shell "$NAME" $sudo nerdctl pull --quiet ${nginx_image}
+			limactl shell "$NAME" $sudo nerdctl run -d --name nginx -p 8888:80 ${nginx_image}
+
+			timeout 3m bash -euxc "until curl -f --retry 30 --retry-connrefused http://${hostip}:8888; do sleep 3; done"
+		fi
+	fi
 	set +x
 fi
 
