@@ -37,30 +37,31 @@ type Network struct {
 	Interface  string
 }
 type Mount struct {
-	Tag     string
-	Target  string // abs path, accessible by the User
-	Type    string
-	Options string
+	Tag        string
+	MountPoint string // abs path, accessible by the User
+	Type       string
+	Options    string
 }
 type TemplateArgs struct {
-	Name            string // instance name
-	IID             string // instance id
-	User            string // user name
-	UID             int
-	SSHPubKeys      []string
-	Mounts          []Mount
-	MountType       string
-	Containerd      Containerd
-	Networks        []Network
-	SlirpNICName    string
-	SlirpGateway    string
-	SlirpDNS        string
-	SlirpIPAddress  string
-	UDPDNSLocalPort int
-	TCPDNSLocalPort int
-	Env             map[string]string
-	DNSAddresses    []string
-	CACerts         CACerts
+	Name               string // instance name
+	IID                string // instance id
+	User               string // user name
+	UID                int
+	SSHPubKeys         []string
+	Mounts             []Mount
+	MountType          string
+	Containerd         Containerd
+	Networks           []Network
+	SlirpNICName       string
+	SlirpGateway       string
+	SlirpDNS           string
+	SlirpIPAddress     string
+	UDPDNSLocalPort    int
+	TCPDNSLocalPort    int
+	Env                map[string]string
+	DNSAddresses       []string
+	CACerts            CACerts
+	HostHomeMountPoint string
 }
 
 func ValidateTemplateArgs(args TemplateArgs) error {
@@ -80,7 +81,7 @@ func ValidateTemplateArgs(args TemplateArgs) error {
 		return errors.New("field SSHPubKeys must be set")
 	}
 	for i, m := range args.Mounts {
-		f := m.Target
+		f := m.MountPoint
 		if !filepath.IsAbs(f) {
 			return fmt.Errorf("field mounts[%d] must be absolute, got %q", i, f)
 		}
