@@ -30,7 +30,7 @@ const (
 )
 
 func defaultContainerdArchives() []File {
-	const nerdctlVersion = "0.20.0"
+	const nerdctlVersion = "0.21.0"
 	location := func(goarch string) string {
 		return "https://github.com/containerd/nerdctl/releases/download/v" + nerdctlVersion + "/nerdctl-full-" + nerdctlVersion + "-linux-" + goarch + ".tar.gz"
 	}
@@ -38,12 +38,12 @@ func defaultContainerdArchives() []File {
 		{
 			Location: location("amd64"),
 			Arch:     X8664,
-			Digest:   "sha256:2aa63b0487c2a500bdf4fc555b51cd7e2128608a8339f02d89810f9e364f86aa",
+			Digest:   "sha256:728f9b543374b1b1733f759608e156dbe578d7b140a081084a1f4bfb4f2b3fbf",
 		},
 		{
 			Location: location("arm64"),
 			Arch:     AARCH64,
-			Digest:   "sha256:eff8546e289ed20e64d17e4d4a50b99cafc0136745ede795d0c9828b8ca50645",
+			Digest:   "sha256:1d0c822f7571042e71ef0b2f8d092f99b0034061726385ca90deaf0b3d2ce3d9",
 		},
 		// No riscv64
 	}
@@ -105,8 +105,10 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		RISCV64: "rv64", // FIXME: what is the right choice for riscv64?
 	}
 	for arch := range cpuType {
-		if IsNativeArch(arch) {
-			cpuType[arch] = "host"
+		if IsNativeArch(arch) && IsAccelOS() {
+			if HasHostCPU() {
+				cpuType[arch] = "host"
+			}
 		}
 	}
 	for k, v := range d.CPUType {
@@ -206,6 +208,26 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		y.SSH.ForwardAgent = pointer.Bool(false)
 	}
 
+	if y.SSH.ForwardX11 == nil {
+		y.SSH.ForwardX11 = d.SSH.ForwardX11
+	}
+	if o.SSH.ForwardX11 != nil {
+		y.SSH.ForwardX11 = o.SSH.ForwardX11
+	}
+	if y.SSH.ForwardX11 == nil {
+		y.SSH.ForwardX11 = pointer.Bool(false)
+	}
+
+	if y.SSH.ForwardX11Trusted == nil {
+		y.SSH.ForwardX11Trusted = d.SSH.ForwardX11Trusted
+	}
+	if o.SSH.ForwardX11Trusted != nil {
+		y.SSH.ForwardX11Trusted = o.SSH.ForwardX11Trusted
+	}
+	if y.SSH.ForwardX11Trusted == nil {
+		y.SSH.ForwardX11Trusted = pointer.Bool(false)
+	}
+
 	hosts := make(map[string]string)
 	// Values can be either names or IP addresses. Name values are canonicalized in the hostResolver.
 	for k, v := range d.HostResolver.Hosts {
@@ -402,6 +424,9 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 			if mount.Writable != nil {
 				mounts[i].Writable = mount.Writable
 			}
+			if mount.MountPoint != "" {
+				mounts[i].MountPoint = mount.MountPoint
+			}
 		} else {
 			location[mount.Location] = len(mounts)
 			mounts = append(mounts, mount)
@@ -439,6 +464,9 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 				mounts[i].NineP.Cache = pointer.String(Default9pCacheForRO)
 			}
 		}
+		if mount.MountPoint == "" {
+			mounts[i].MountPoint = mount.Location
+		}
 	}
 
 	if y.MountType == nil {
@@ -586,6 +614,27 @@ func ResolveArch(s *string) Arch {
 	return *s
 }
 
+func IsAccelOS() bool {
+	switch runtime.GOOS {
+	case "darwin", "linux", "netbsd", "windows":
+		// Accelerator
+		return true
+	}
+	// Using TCG
+	return false
+}
+
+func HasHostCPU() bool {
+	switch runtime.GOOS {
+	case "darwin", "linux":
+		return true
+	case "netbsd", "windows":
+		return false
+	}
+	// Not reached
+	return false
+}
+
 func IsNativeArch(arch Arch) bool {
 	nativeX8664 := arch == X8664 && runtime.GOARCH == "amd64"
 	nativeAARCH64 := arch == AARCH64 && runtime.GOARCH == "arm64"
