@@ -65,6 +65,8 @@ func TestFillDefault(t *testing.T) {
 			LocalPort:         pointer.Int(0),
 			LoadDotSSHPubKeys: pointer.Bool(true),
 			ForwardAgent:      pointer.Bool(false),
+			ForwardX11:        pointer.Bool(false),
+			ForwardX11Trusted: pointer.Bool(false),
 		},
 		Firmware: Firmware{
 			LegacyBIOS: pointer.Bool(false),
@@ -81,7 +83,11 @@ func TestFillDefault(t *testing.T) {
 			RemoveDefaults: pointer.Bool(false),
 		},
 	}
-	builtin.CPUType[arch] = "host"
+	if IsAccelOS() {
+		if HasHostCPU() {
+			builtin.CPUType[arch] = "host"
+		}
+	}
 
 	defaultPortForward := PortForward{
 		GuestIP:        api.IPv4loopback1,
@@ -145,6 +151,7 @@ func TestFillDefault(t *testing.T) {
 	}
 
 	expect.Mounts = y.Mounts
+	expect.Mounts[0].MountPoint = expect.Mounts[0].Location
 	expect.Mounts[0].Writable = pointer.Bool(false)
 	expect.Mounts[0].SSHFS.Cache = pointer.Bool(true)
 	expect.Mounts[0].SSHFS.FollowSymlinks = pointer.Bool(false)
@@ -229,6 +236,8 @@ func TestFillDefault(t *testing.T) {
 			LocalPort:         pointer.Int(888),
 			LoadDotSSHPubKeys: pointer.Bool(false),
 			ForwardAgent:      pointer.Bool(true),
+			ForwardX11:        pointer.Bool(false),
+			ForwardX11Trusted: pointer.Bool(false),
 		},
 		Firmware: Firmware{
 			LegacyBIOS: pointer.Bool(true),
@@ -299,6 +308,7 @@ func TestFillDefault(t *testing.T) {
 	expect = d
 	// Also verify that archive arch is filled in
 	expect.Containerd.Archives[0].Arch = *d.Arch
+	expect.Mounts[0].MountPoint = expect.Mounts[0].Location
 	expect.Mounts[0].SSHFS.Cache = pointer.Bool(true)
 	expect.Mounts[0].SSHFS.FollowSymlinks = pointer.Bool(false)
 	expect.Mounts[0].SSHFS.SFTPDriver = pointer.String("")
@@ -374,6 +384,8 @@ func TestFillDefault(t *testing.T) {
 			LocalPort:         pointer.Int(4433),
 			LoadDotSSHPubKeys: pointer.Bool(true),
 			ForwardAgent:      pointer.Bool(true),
+			ForwardX11:        pointer.Bool(false),
+			ForwardX11Trusted: pointer.Bool(false),
 		},
 		Firmware: Firmware{
 			LegacyBIOS: pointer.Bool(true),
