@@ -284,6 +284,10 @@ func getMacOSProductVersion() (*semver.Version, error) {
 		return nil, fmt.Errorf("failed to execute %v: %w", cmd.Args, err)
 	}
 	verTrimmed := strings.TrimSpace(string(b))
+	// macOS 12.4 returns just "12.4\n"
+	for strings.Count(verTrimmed, ".") < 2 {
+		verTrimmed += ".0"
+	}
 	verSem, err := semver.NewVersion(verTrimmed)
 	if err != nil {
 		return nil, fmt.Errorf("failed to parse macOS version %q: %w", verTrimmed, err)
@@ -539,16 +543,16 @@ func Cmdline(cfg Config) (string, []string, error) {
 	if *y.MountType == limayaml.NINEP {
 		for i, f := range y.Mounts {
 			tag := fmt.Sprintf("mount%d", i)
-			expanded, err := localpathutil.Expand(f.Location)
+			location, err := localpathutil.Expand(f.Location)
 			if err != nil {
 				return "", nil, err
 			}
-			if err := os.MkdirAll(expanded, 0755); err != nil {
+			if err := os.MkdirAll(location, 0755); err != nil {
 				return "", nil, err
 			}
 			options := "local"
 			options += fmt.Sprintf(",mount_tag=%s", tag)
-			options += fmt.Sprintf(",path=%s", expanded)
+			options += fmt.Sprintf(",path=%s", location)
 			options += fmt.Sprintf(",security_model=%s", *f.NineP.SecurityModel)
 			if !*f.Writable {
 				options += ",readonly"
